==> kubernetes-client_2.13-0.10.0-sources.jar: NetworkPolicy.scala <==
package io.k8s.api.networking.v1

import io.circe.*
import io.circe.generic.semiauto.*

/** NetworkPolicy describes what network traffic is allowed for a set of Pods
 *
 *  @param apiVersion  APIVersion defines the versioned schema of this representation of an object. Servers should convert
 *                     recognized schemas to the latest internal value, and may reject unrecognized values. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
 *  @param       kind  Kind is a string value representing the REST resource this object represents. Servers may infer this
 *                     from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
 *  @param   metadata  Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
 *  @param       spec  Specification of the desired behavior for this NetworkPolicy.
 *  @param     status  Status is the current state of the NetworkPolicy. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
*/
case class NetworkPolicy(
  apiVersion: Option[String] = None,
  kind: Option[String] = None,
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  spec: Option[io.k8s.api.networking.v1.NetworkPolicySpec] = None,
  status: Option[io.k8s.api.networking.v1.NetworkPolicyStatus] = None
)

object NetworkPolicy {
  implicit lazy val encoder: Encoder.AsObject[NetworkPolicy] = deriveEncoder
  implicit lazy val decoder: Decoder[NetworkPolicy] = deriveDecoder
}

==> kubernetes-client_3-0.11.1-sources.jar: NetworkPolicy.scala <==
package io.k8s.api.networking.v1

import io.circe.*
import io.circe.generic.semiauto.*

/** NetworkPolicy describes what network traffic is allowed for a set of Pods
 *
 *  @param apiVersion  APIVersion defines the versioned schema of this representation of an object. Servers should convert
 *                     recognized schemas to the latest internal value, and may reject unrecognized values. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
 *  @param       kind  Kind is a string value representing the REST resource this object represents. Servers may infer this
 *                     from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
 *  @param   metadata  Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
 *  @param       spec  spec represents the specification of the desired behavior for this NetworkPolicy.
*/
case class NetworkPolicy(
  apiVersion: Option[String] = None,
  kind: Option[String] = None,
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  spec: Option[io.k8s.api.networking.v1.NetworkPolicySpec] = None
)

object NetworkPolicy {
  implicit lazy val encoder: Encoder.AsObject[NetworkPolicy] = deriveEncoder
  implicit lazy val decoder: Decoder[NetworkPolicy] = deriveDecoder
}
